@@ -38,7 +38,7 @@ function early_exception_handler($e) {
   foreach( $trace AS $k => $v ) {
     printf( "%s[%d] %s%s%s()\n", $v['file'], $v['line'], (isset($v['class'])?$v['class']:''), (isset($v['type'])?$v['type']:''), (isset($v['function'])?$v['function']:'') );
   }
-
+  error_log("PHP Early Exception: [".$e->getCode()."] ".$e->getmessage()." at ".$e->getFile().":".$e->getLine());
 }
 set_exception_handler('early_exception_handler');
 
@@ -184,20 +184,20 @@ ob_end_clean();
 * Override server-detected variables with those from X-Forwarded headers
 */
 if ( isset($c->trust_x_forwarded) && $c->trust_x_forwarded ) {
-  if ( isset($_SERVER['X-Real-IP']) ) {
-    $_SERVER['REMOTE_ADDR'] = $_SERVER['X-Real-IP'];
-  } elseif ( isset($_SERVER['X-Forwarded-For']) ) {
-    list($_SERVER['REMOTE_ADDR'], $rest) = explode( ',', $_SERVER['X-Forwarded-For']);
+  if ( isset($_SERVER['HTTP_X_REAL_IP']) ) {
+    $_SERVER['REMOTE_ADDR'] = $_SERVER['HTTP_X_REAL_IP'];
+  } elseif ( isset($_SERVER['HTTP_X_FORWARDED_FOR']) ) {
+    list($_SERVER['REMOTE_ADDR'], $rest) = explode( ',', $_SERVER['HTTP_X_FORWARDED_FOR']);
   }
-  if ( isset($_SERVER['X-Forwarded-Proto']) ) {
-    if ($_SERVER['X-Forwarded-Proto'] == 'https') {
+  if ( isset($_SERVER['HTTP_X_FORWARDED_PROTO']) ) {
+    if ($_SERVER['HTTP_X_FORWARDED_PROTO'] == 'https') {
       $_SERVER['HTTPS'] = 'on';
     } else {
       $_SERVER['HTTPS'] = 'off';
     }
   }
-  if ( isset($_SERVER['X-Forwarded-Port']) ) {
-    $_SERVER['SERVER_PORT'] = $_SERVER['X-Forwarded-Port'];
+  if ( isset($_SERVER['HTTP_X_FORWARDED_PORT']) ) {
+    $_SERVER['SERVER_PORT'] = $_SERVER['HTTP_X_FORWARDED_PORT'];
   }
 }
 
@@ -244,8 +244,8 @@ if ( function_exists('awl_set_locale') ) {
 *
 */
 $c->code_version = 0;
-$c->want_awl_version = '0.57';
-$c->version_string = '1.1.5'; // The actual version # is replaced into that during the build /release process
+$c->want_awl_version = '0.58';
+$c->version_string = '1.1.6'; // The actual version # is replaced into that during the build /release process
 if ( isset($c->version_string) && preg_match( '/(\d+)\.(\d+)\.(\d+)(.*)/', $c->version_string, $matches) ) {
   $c->code_major = $matches[1];
   $c->code_minor = $matches[2];
@@ -367,6 +367,11 @@ function ConstructURL( $partial_path, $force_script = false ) {
     $url = str_replace( 'caldav.php/caldav.php', 'caldav.php', $url );  // Ensure we don't double any 'caldav.php/'
   }
 
+  // don't put the script name in special URLs, these would not be valid resources
+  $url = str_replace('/principals/users/caldav.php/', '/principals/users/', $url );
+  $url = str_replace('/principals/resources/caldav.php/', '/principals/resources/', $url );
+  $url = str_replace('/__uids__/caldav.php/', '/__uids__/', $url );
+
   return $url;
 }
 
