@@ -102,7 +102,7 @@ if ( ! ($request->IsPrincipal() || isset($request->collection) || $request->meth
     @ob_flush(); exit(0);
   }
 }
-param_to_global('add_member', '.*', 'add-member');
+param_to_global('add_member', null, 'add-member');
 $add_member = isset($add_member);
 
 try {
@@ -154,7 +154,7 @@ try {
   }
 
 } catch (Exception $e) {
-  trace_bug('DAViCal Fatal Error');
+  trace_bug( 'DAViCal Fatal Error: ['.$e->getCode().'] '.$e->getmessage().' at '.$e->getFile().':'.$e->getLine() );
   $request->DoResponse( 500, translate('DAViCal Fatal Error') );
 }
 
