@@ -385,7 +385,7 @@ function LDAP_check($username, $password ){
     return false;
   }
 
-  if ( $mapping['modified'] != "" && in_array($mapping['modified'], $valid)) {
+  if ( $mapping['modified'] != "" && array_key_exists($mapping['modified'], $valid)) {
     $ldap_timestamp = $valid[$mapping['modified']];
   } else {
     $ldap_timestamp = '19700101000000';
@@ -398,7 +398,7 @@ function LDAP_check($username, $password ){
     $$k = substr($ldap_timestamp,$v[0],$v[1]);
 
   $ldap_timestamp = "$Y"."$m"."$d"."$H"."$M"."$S";
-  if ($mapping['modified'] != "" && in_array($mapping['modified'], $valid)) {
+  if ($mapping['modified'] != "" && array_key_exists($mapping['modified'], $valid)) {
     $valid[$mapping['modified']] = "$Y-$m-$d $H:$M:$S";
   }
 
@@ -594,6 +594,7 @@ function sync_LDAP(){
   if ( sizeof($ldap_users_tmp) == 0 ) return;
 
   foreach($ldap_users_tmp as $key => $ldap_user){
+    if(!isset($ldap_user[$mapping['username']])) continue;
     $ldap_users_info[$ldap_user[$mapping['username']]] = $ldap_user;
     unset($ldap_users_tmp[$key]);
   }
@@ -620,7 +621,7 @@ function sync_LDAP(){
     foreach( $users_to_create as $username ) {
       $principal = new Principal( 'username', $username );
       $valid = $ldap_users_info[$username];
-      if ( $mapping['modified'] != "" && in_array($mapping['modified'], $valid)) {
+      if ( $mapping['modified'] != "" && array_key_exists($mapping['modified'], $valid)) {
         $ldap_timestamp = $valid[$mapping['modified']];
       } else {
         $ldap_timestamp = '19700101000000';
@@ -640,7 +641,7 @@ function sync_LDAP(){
       else if ( empty($ldap_timestamp) ) {
         $ldap_timestamp = date('c');
       }
-      if ( $mapping['modified'] != "" && in_array($mapping['modified'], $valid)) {
+      if ( $mapping['modified'] != "" && array_key_exists($mapping['modified'], $valid)) {
         $valid[$mapping['modified']] = $ldap_timestamp;
       }
 
@@ -652,8 +653,12 @@ function sync_LDAP(){
   $params = array();
   $i = 0;
   $paramstring = '';
-  foreach( $users_to_deactivate AS $v ) {
-    if ( isset($c->do_not_sync_from_ldap) && isset($c->do_not_sync_from_ldap[$v]) ) continue;
+  foreach( $users_to_deactivate as $k => $v ) {
+    if ( isset($c->do_not_sync_from_ldap) && isset($c->do_not_sync_from_ldap[$v]) ) {
+      unset($users_to_deactivate[$k]);
+      $users_nothing_done[] = $v;
+      continue;
+    }
     if ( $i > 0 ) $paramstring .= ',';
     $paramstring .= ':u'.$i.'::text';
     $params[':u'.$i++] = strtolower($v);
@@ -671,7 +676,7 @@ function sync_LDAP(){
     foreach ( $users_to_update as $key=> $username ) {
       $principal = new Principal( 'username', $username );
       $valid=$ldap_users_info[$username];
-      if ( $mapping['modified'] != "" && in_array($mapping['modified'], $valid)) {
+      if ( $mapping['modified'] != "" && array_key_exists($mapping['modified'], $valid)) {
         $ldap_timestamp = $valid[$mapping['modified']];
       } else {
         $ldap_timestamp = '19700101000000';
